@@ -27,10 +27,7 @@ all_losses <- c("sq_loss_lasso",
                 "owl_logistic_flip_loss_gam",
                 "owl_logistic_loss_lasso_gam",
                 "owl_logistic_flip_loss_lasso_gam",
-                "sq_loss_gbm",
-                "poisson_loss_gbm",
-                "logistic_loss_gbm",
-                "cox_loss_gbm",
+                "sq_loss_xgboost",
                 "custom")
 
 calc_treatment_effects <- function(benefit.scores,
@@ -52,10 +49,7 @@ calc_treatment_effects <- function(benefit.scores,
                                             "owl_logistic_flip_loss_gam",
                                             "owl_logistic_loss_lasso_gam",
                                             "owl_logistic_flip_loss_lasso_gam",
-                                            "sq_loss_gbm",
-                                            "poisson_loss_gbm",
-                                            "logistic_loss_gbm",
-                                            "cox_loss_gbm",
+                                            "sq_loss_xgboost",
                                             "custom"),
                                    method = c("weighting", "a_learning"),
                                    pi.x = NULL)
@@ -167,10 +161,7 @@ treat.effects <- function(benefit.scores,
                                    "owl_logistic_flip_loss_gam",
                                    "owl_logistic_loss_lasso_gam",
                                    "owl_logistic_flip_loss_lasso_gam",
-                                   "sq_loss_gbm",
-                                   "poisson_loss_gbm",
-                                   "logistic_loss_gbm",
-                                   "cox_loss_gbm",
+                                   "sq_loss_xgboost",
                                    "custom"),
                           method = c("weighting", "a_learning"),
                           pi.x = NULL, ...)
@@ -192,13 +183,13 @@ treat.effects <- function(benefit.scores,
 #' library(personalized)
 #'
 #' set.seed(123)
-#' n.obs  <- 1000
-#' n.vars <- 50
+#' n.obs  <- 500
+#' n.vars <- 25
 #' x <- matrix(rnorm(n.obs * n.vars, sd = 3), n.obs, n.vars)
 #'
 #'
 #' # simulate non-randomized treatment
-#' xbetat   <- 0.5 + 0.5 * x[,21] - 0.5 * x[,41]
+#' xbetat   <- 0.5 + 0.5 * x[,21] - 0.5 * x[,11]
 #' trt.prob <- exp(xbetat) / (1 + exp(xbetat))
 #' trt01    <- rbinom(n.obs, 1, prob = trt.prob)
 #'
@@ -233,7 +224,7 @@ treat.effects <- function(benefit.scores,
 #'                              trt = trt01,
 #'                              propensity.func = prop.func,
 #'                              loss   = "sq_loss_lasso",
-#'                              nfolds = 5)    # option for cv.glmnet
+#'                              nfolds = 3)    # option for cv.glmnet
 #'
 #' trt_eff <- treatment.effects(subgrp.model)
 #' str(trt_eff)
@@ -246,7 +237,7 @@ treat.effects <- function(benefit.scores,
 #'                            trt = trt01,
 #'                            propensity.func = prop.func,
 #'                            loss   = "cox_loss_lasso",
-#'                            nfolds = 5)              # option for cv.glmnet
+#'                            nfolds = 3)              # option for cv.glmnet
 #'
 #' trt_eff_c <- treatment.effects(subgrp.model.cox)
 #' str(trt_eff_c)
